local assets =
{
    Asset("ANIM", "anim/twigs.zip"),
    Asset("ATLAS", "images/inventoryimages/magicaltwigs.xml"),
}


local function twigslightfn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddLight()
    
    inst:AddTag("FX")

    inst.Light:SetIntensity(0.5)
    inst.Light:SetRadius(10)
    inst.Light:Enable(true)
    inst.Light:SetFalloff(1)
    inst.Light:SetColour(200/255, 100/255, 170/255)

    inst.persists = false

    return inst
end


local function lighton(inst, owner)
    if inst._light == nil or not inst._light:IsValid() then
        inst._light = SpawnPrefab("twigslight")
    end
    if owner ~= nil then
        inst._light.entity:SetParent(owner.entity)
    end
end


local function lightoff(inst)
    if inst._light ~= nil then
            if inst._light:IsValid() then
                inst._light:Remove()
            end
            inst._light = nil
        end
end

local function onequip(inst, owner)
    owner.AnimState:OverrideSymbol("swap_object", "twigs", "twigs")
    owner.AnimState:Show("ARM_carry")
    owner.AnimState:Hide("ARM_normal")

    lighton(inst, owner)
end


local function onunequip(inst, owner)
    owner.AnimState:Hide("ARM_carry")
    owner.AnimState:Show("ARM_normal")

    lightoff(inst, owner)
end


local function fn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddLight()
    
    MakeInventoryPhysics(inst)

    inst.Light:SetIntensity(0.5)
    inst.Light:SetRadius(10)
    inst.Light:Enable(true)
    inst.Light:SetFalloff(1)
    inst.Light:SetColour(200/255, 100/255, 170/255)

    inst.AnimState:SetBank("magicaltwigs")
    inst.AnimState:SetBuild("magicaltwigs")
    inst.AnimState:PlayAnimation("idle")

    inst:AddTag("sharp")

    -----
    inst:AddComponent("tool")
    inst.components.tool:SetAction(ACTIONS.MINE, 12) --可挖矿
    inst.components.tool:SetAction(ACTIONS.CHOP, 12) --可砍树
    inst.components.tool:SetAction(ACTIONS.DIG)  --可挖
    inst.components.tool:SetAction(ACTIONS.NET)  --可捕虫
    inst.components.tool:SetAction(ACTIONS.HAMMER) --可重击
	inst.components.tool:SetAction(ACTIONS.HACK, 12)--可劈砍
    --inst:AddInherentAction(ACTIONS.TERRAFORM)    --可铲草

    inst:AddComponent("weapon")
    inst.components.weapon:SetDamage(100)
    inst.components.weapon:SetRange(6,6)

    inst:AddComponent("inspectable")
	inst:AddComponent("waterproofer")
    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.atlasname = "images/inventoryimages/magicaltwigs.xml"
   
    inst:AddComponent("equippable")
    inst.components.equippable:SetOnEquip(onequip)
    inst.components.equippable:SetOnUnequip(onunequip)
    inst.components.equippable.walkspeedmult = 2

    return inst
end

return Prefab("common/inventory/magicaltwigs", fn, assets),
       Prefab("twigslight", twigslightfn)
